[go/dev.simd] [dev.simd] simd: reorganize simdgen YAML configs by architecture

6 views
Skip to first unread message

Alexander Musman (Gerrit)

unread,
May 1, 2026, 4:08:13 PMMay 1
to goph...@pubsubhelper.golang.org, golang-co...@googlegroups.com

Alexander Musman has uploaded the change for review

Commit message

[dev.simd] simd: reorganize simdgen YAML configs by architecture

Rename go.yaml to go_amd64.yaml and add go_arm64.yaml alongside it in
the shared ops/ directory, instead of using a separate arm64/ directory.
This keeps amd64 and arm64 configs symmetric under the same directory
structure and avoids duplicating the architecture-neutral categories.yaml
files.

No generated output changes beyond the "Code generated by" header line.
Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5

Change diff

diff --git a/src/cmd/compile/internal/amd64/simdssa.go b/src/cmd/compile/internal/amd64/simdssa.go
index 0e3c246..e0b4786d 100644
--- a/src/cmd/compile/internal/amd64/simdssa.go
+++ b/src/cmd/compile/internal/amd64/simdssa.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package amd64

diff --git a/src/cmd/compile/internal/arm64/simdssa.go b/src/cmd/compile/internal/arm64/simdssa.go
index 6faf723..c4a9148 100644
--- a/src/cmd/compile/internal/arm64/simdssa.go
+++ b/src/cmd/compile/internal/arm64/simdssa.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package arm64

diff --git a/src/cmd/compile/internal/ssa/_gen/simdAMD64.rules b/src/cmd/compile/internal/ssa/_gen/simdAMD64.rules
index 3816aaa..21091e6 100644
--- a/src/cmd/compile/internal/ssa/_gen/simdAMD64.rules
+++ b/src/cmd/compile/internal/ssa/_gen/simdAMD64.rules
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

(AESDecryptLastRoundUint8x16 ...) => (VAESDECLAST128 ...)
(AESDecryptLastRoundUint8x32 ...) => (VAESDECLAST256 ...)
diff --git a/src/cmd/compile/internal/ssa/_gen/simdAMD64ops.go b/src/cmd/compile/internal/ssa/_gen/simdAMD64ops.go
index 8cd409f..49f0a46 100644
--- a/src/cmd/compile/internal/ssa/_gen/simdAMD64ops.go
+++ b/src/cmd/compile/internal/ssa/_gen/simdAMD64ops.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package main

diff --git a/src/cmd/compile/internal/ssa/_gen/simdARM64.rules b/src/cmd/compile/internal/ssa/_gen/simdARM64.rules
index 4444280..b26a0e4 100644
--- a/src/cmd/compile/internal/ssa/_gen/simdARM64.rules
+++ b/src/cmd/compile/internal/ssa/_gen/simdARM64.rules
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

(AddFloat32x4 ...) => (VFADD4S ...)
(AddFloat64x2 ...) => (VFADD2D ...)
diff --git a/src/cmd/compile/internal/ssa/_gen/simdARM64ops.go b/src/cmd/compile/internal/ssa/_gen/simdARM64ops.go
index deeebd7..034fd89 100644
--- a/src/cmd/compile/internal/ssa/_gen/simdARM64ops.go
+++ b/src/cmd/compile/internal/ssa/_gen/simdARM64ops.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package main

diff --git a/src/cmd/compile/internal/ssagen/simdAMD64intrinsics.go b/src/cmd/compile/internal/ssagen/simdAMD64intrinsics.go
index 9689852..7c482a6 100644
--- a/src/cmd/compile/internal/ssagen/simdAMD64intrinsics.go
+++ b/src/cmd/compile/internal/ssagen/simdAMD64intrinsics.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package ssagen

diff --git a/src/cmd/compile/internal/ssagen/simdARM64intrinsics.go b/src/cmd/compile/internal/ssagen/simdARM64intrinsics.go
index 3aea969..d7b1f28 100644
--- a/src/cmd/compile/internal/ssagen/simdARM64intrinsics.go
+++ b/src/cmd/compile/internal/ssagen/simdARM64intrinsics.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

package ssagen

diff --git a/src/simd/archsimd/_gen/simdgen/arch.go b/src/simd/archsimd/_gen/simdgen/arch.go
index 0ed1033..48cf25d 100644
--- a/src/simd/archsimd/_gen/simdgen/arch.go
+++ b/src/simd/archsimd/_gen/simdgen/arch.go
@@ -85,10 +85,10 @@

const arm64RegInfoParams = "v21 regInfo"

-const amd64GeneratedHeader = `// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+const amd64GeneratedHeader = `// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.
`

-const arm64GeneratedHeader = `// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+const arm64GeneratedHeader = `// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.
`

// GetArchInfo returns architecture-specific information based on the target architecture.
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/categories.yaml b/src/simd/archsimd/_gen/simdgen/arm64/categories.yaml
deleted file mode 100644
index ed4c964..0000000
--- a/src/simd/archsimd/_gen/simdgen/arm64/categories.yaml
+++ /dev/null
@@ -1 +0,0 @@
-!import ops/*/categories.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/go.yaml b/src/simd/archsimd/_gen/simdgen/arm64/go.yaml
deleted file mode 100644
index 4f077c8..0000000
--- a/src/simd/archsimd/_gen/simdgen/arm64/go.yaml
+++ /dev/null
@@ -1 +0,0 @@
-!import ops/*/go.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/categories.yaml b/src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/categories.yaml
deleted file mode 100644
index 33fe1a9..0000000
--- a/src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/categories.yaml
+++ /dev/null
@@ -1,9 +0,0 @@
-!sum
-- go: Add
- commutative: true
- documentation: !string |-
- // NAME adds corresponding elements of two vectors.
-- go: Sub
- commutative: false
- documentation: !string |-
- // NAME subtracts corresponding elements of two vectors.
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/categories.yaml b/src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/categories.yaml
deleted file mode 100644
index 301debc..0000000
--- a/src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/categories.yaml
+++ /dev/null
@@ -1,5 +0,0 @@
-!sum
-- go: Mul
- commutative: true
- documentation: !string |-
- // NAME multiplies corresponding elements of two vectors.
diff --git a/src/simd/archsimd/_gen/simdgen/etetest.sh b/src/simd/archsimd/_gen/simdgen/etetest.sh
index 0bd2354..8e800e1 100755
--- a/src/simd/archsimd/_gen/simdgen/etetest.sh
+++ b/src/simd/archsimd/_gen/simdgen/etetest.sh
@@ -22,7 +22,7 @@
set -ex

# Regenerate SIMD files
-go run . -o godefs -goroot "$goroot" -xedPath "$XEDDATA" go.yaml types.yaml categories.yaml
+go run . -o godefs -goroot "$goroot" -xedPath "$XEDDATA" go_amd64.yaml types.yaml categories.yaml
# Regenerate SSA files from SIMD rules
go run -C "$goroot"/src/cmd/compile/internal/ssa/_gen .

diff --git a/src/simd/archsimd/_gen/simdgen/go.yaml b/src/simd/archsimd/_gen/simdgen/go.yaml
deleted file mode 100644
index 4f077c8..0000000
--- a/src/simd/archsimd/_gen/simdgen/go.yaml
+++ /dev/null
@@ -1 +0,0 @@
-!import ops/*/go.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/go_amd64.yaml b/src/simd/archsimd/_gen/simdgen/go_amd64.yaml
new file mode 100644
index 0000000..58fc721
--- /dev/null
+++ b/src/simd/archsimd/_gen/simdgen/go_amd64.yaml
@@ -0,0 +1 @@
+!import ops/*/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/go_arm64.yaml b/src/simd/archsimd/_gen/simdgen/go_arm64.yaml
new file mode 100644
index 0000000..f9fd5e2
--- /dev/null
+++ b/src/simd/archsimd/_gen/simdgen/go_arm64.yaml
@@ -0,0 +1 @@
+!import ops/*/go_arm64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/AddSub/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/AddSub/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/AddSub/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/AddSub/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/AddSub/go_arm64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/AddSub/go_arm64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/BitwiseLogic/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/BitwiseLogic/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/BitwiseLogic/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/BitwiseLogic/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/Compares/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Compares/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/Compares/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Compares/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/Converts/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Converts/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/Converts/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Converts/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/FPonlyArith/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/FPonlyArith/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/FPonlyArith/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/FPonlyArith/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/GaloisField/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/GaloisField/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/GaloisField/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/GaloisField/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/IntOnlyArith/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/IntOnlyArith/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/IntOnlyArith/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/IntOnlyArith/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/MLOps/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/MLOps/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/MLOps/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/MLOps/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/MinMax/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/MinMax/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/MinMax/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/MinMax/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/Moves/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Moves/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/Moves/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Moves/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/Mul/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Mul/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/Mul/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Mul/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Mul/go_arm64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Mul/go_arm64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/Others/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/Others/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/Others/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/Others/go_amd64.yaml
diff --git a/src/simd/archsimd/_gen/simdgen/ops/ShiftRotate/go.yaml b/src/simd/archsimd/_gen/simdgen/ops/ShiftRotate/go_amd64.yaml
similarity index 100%
rename from src/simd/archsimd/_gen/simdgen/ops/ShiftRotate/go.yaml
rename to src/simd/archsimd/_gen/simdgen/ops/ShiftRotate/go_amd64.yaml
diff --git a/src/simd/archsimd/cpu.go b/src/simd/archsimd/cpu.go
index a25556a..6a8181c 100644
--- a/src/simd/archsimd/cpu.go
+++ b/src/simd/archsimd/cpu.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/ops_amd64.go b/src/simd/archsimd/ops_amd64.go
index 830bd54..81778c0 100644
--- a/src/simd/archsimd/ops_amd64.go
+++ b/src/simd/archsimd/ops_amd64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/ops_arm64.go b/src/simd/archsimd/ops_arm64.go
index 75c5827..65f0cf4 100644
--- a/src/simd/archsimd/ops_arm64.go
+++ b/src/simd/archsimd/ops_arm64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/ops_internal_amd64.go b/src/simd/archsimd/ops_internal_amd64.go
index 8aaacf6..4786c33 100644
--- a/src/simd/archsimd/ops_internal_amd64.go
+++ b/src/simd/archsimd/ops_internal_amd64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/ops_internal_arm64.go b/src/simd/archsimd/ops_internal_arm64.go
index 10444a6..b8b3e93 100644
--- a/src/simd/archsimd/ops_internal_arm64.go
+++ b/src/simd/archsimd/ops_internal_arm64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/types_amd64.go b/src/simd/archsimd/types_amd64.go
index 3d0a49d..8302859 100644
--- a/src/simd/archsimd/types_amd64.go
+++ b/src/simd/archsimd/types_amd64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go.yaml types.yaml categories.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -xedPath $XED_PATH go_amd64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

diff --git a/src/simd/archsimd/types_arm64.go b/src/simd/archsimd/types_arm64.go
index 43476a7..2f4fb27 100644
--- a/src/simd/archsimd/types_arm64.go
+++ b/src/simd/archsimd/types_arm64.go
@@ -1,4 +1,4 @@
-// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH arm64/go.yaml arm64/categories.yaml types.yaml'; DO NOT EDIT.
+// Code generated by 'simdgen -o godefs -goroot $GOROOT -arm64Path $ARM64_ISA_PATH go_arm64.yaml types.yaml categories.yaml'; DO NOT EDIT.

//go:build goexperiment.simd

Change information

Files:
  • M src/cmd/compile/internal/amd64/simdssa.go
  • M src/cmd/compile/internal/arm64/simdssa.go
  • M src/cmd/compile/internal/ssa/_gen/simdAMD64.rules
  • M src/cmd/compile/internal/ssa/_gen/simdAMD64ops.go
  • M src/cmd/compile/internal/ssa/_gen/simdARM64.rules
  • M src/cmd/compile/internal/ssa/_gen/simdARM64ops.go
  • M src/cmd/compile/internal/ssagen/simdAMD64intrinsics.go
  • M src/cmd/compile/internal/ssagen/simdARM64intrinsics.go
  • M src/simd/archsimd/_gen/main.go
  • M src/simd/archsimd/_gen/simdgen/arch.go
  • D src/simd/archsimd/_gen/simdgen/arm64/categories.yaml
  • D src/simd/archsimd/_gen/simdgen/arm64/go.yaml
  • D src/simd/archsimd/_gen/simdgen/arm64/ops/AddSub/categories.yaml
  • D src/simd/archsimd/_gen/simdgen/arm64/ops/Mul/categories.yaml
  • M src/simd/archsimd/_gen/simdgen/etetest.sh
  • D src/simd/archsimd/_gen/simdgen/go.yaml
  • A src/simd/archsimd/_gen/simdgen/go_amd64.yaml
  • A src/simd/archsimd/_gen/simdgen/go_arm64.yaml
  • M src/simd/archsimd/_gen/simdgen/main.go
  • R src/simd/archsimd/_gen/simdgen/ops/AddSub/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/AddSub/go_arm64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/BitwiseLogic/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Compares/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Converts/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/FPonlyArith/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/GaloisField/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/IntOnlyArith/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/MLOps/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/MinMax/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Moves/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Mul/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Mul/go_arm64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/Others/go_amd64.yaml
  • R src/simd/archsimd/_gen/simdgen/ops/ShiftRotate/go_amd64.yaml
  • M src/simd/archsimd/cpu.go
  • M src/simd/archsimd/ops_amd64.go
  • M src/simd/archsimd/ops_arm64.go
  • M src/simd/archsimd/ops_internal_amd64.go
  • M src/simd/archsimd/ops_internal_arm64.go
  • M src/simd/archsimd/types_amd64.go
  • M src/simd/archsimd/types_arm64.go
Change size: M
Delta: 41 files changed, 38 insertions(+), 44 deletions(-)
Open in Gerrit

Related details

Attention set is empty
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: newchange
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 1
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
unsatisfied_requirement
satisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
May 1, 2026, 4:17:04 PMMay 1
to goph...@pubsubhelper.golang.org, Cherry Mui, David Chase, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Cherry Mui, David Chase and Junyang Shao

Alexander Musman added 1 comment

Patchset-level comments
File-level comment, Patchset 1 (Latest):
Alexander Musman . resolved

I suggest to do this config update in separate CL (this), to simplify review. This makes it without functional changes (the only diff in generated files is updated "Code generated by ..." comment).

Open in Gerrit

Related details

Attention is currently required from:
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 1
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: David Chase <drc...@google.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Fri, 01 May 2026 20:16:58 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
unsatisfied_requirement
satisfied_requirement
open
diffy

David Chase (Gerrit)

unread,
May 2, 2026, 9:34:42 AMMay 2
to Alexander Musman, goph...@pubsubhelper.golang.org, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui and Junyang Shao

David Chase voted

Code-Review+2
Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • Junyang Shao
Submit Requirements:
  • requirement satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 1
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: Alexander Musman <alexande...@gmail.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Sat, 02 May 2026 13:34:38 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
satisfied_requirement
unsatisfied_requirement
open
diffy

David Chase (Gerrit)

unread,
May 4, 2026, 11:47:12 AMMay 4
to Alexander Musman, goph...@pubsubhelper.golang.org, golang...@luci-project-accounts.iam.gserviceaccount.com, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui and Junyang Shao

David Chase voted

Code-Review+2
Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • Junyang Shao
Submit Requirements:
  • requirement satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 2
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: Alexander Musman <alexande...@gmail.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Mon, 04 May 2026 15:47:09 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
satisfied_requirement
unsatisfied_requirement
open
diffy

David Chase (Gerrit)

unread,
May 6, 2026, 10:25:50 AM (13 days ago) May 6
to Alexander Musman, goph...@pubsubhelper.golang.org, golang...@luci-project-accounts.iam.gserviceaccount.com, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui and Junyang Shao

David Chase voted

Code-Review+2
Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • Junyang Shao
Submit Requirements:
  • requirement satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 3
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: Alexander Musman <alexande...@gmail.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Wed, 06 May 2026 14:25:46 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
satisfied_requirement
unsatisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
May 8, 2026, 1:42:13 PM (11 days ago) May 8
to goph...@pubsubhelper.golang.org, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui, David Chase and Junyang Shao

Alexander Musman uploaded new patchset

Alexander Musman uploaded patch set #4 to this change.
Following approvals got outdated and were removed:
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: newpatchset
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 4
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: David Chase <drc...@google.com>
unsatisfied_requirement
satisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
May 9, 2026, 2:19:11 AM (10 days ago) May 9
to goph...@pubsubhelper.golang.org, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui, David Chase and Junyang Shao

Alexander Musman uploaded new patchset

Alexander Musman uploaded patch set #5 to this change.
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: newpatchset
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 5
unsatisfied_requirement
satisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
May 9, 2026, 2:20:24 AM (10 days ago) May 9
to goph...@pubsubhelper.golang.org, golang...@luci-project-accounts.iam.gserviceaccount.com, David Chase, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Cherry Mui, David Chase and Junyang Shao

Alexander Musman voted Commit-Queue+1

Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 5
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: David Chase <drc...@google.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Sat, 09 May 2026 06:20:16 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
unsatisfied_requirement
satisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
May 18, 2026, 11:24:26 AM (21 hours ago) May 18
to goph...@pubsubhelper.golang.org, golang-co...@googlegroups.com
Attention needed from Cherry Mui, David Chase and Junyang Shao

Alexander Musman uploaded new patchset

Alexander Musman uploaded patch set #6 to this change.
Following approvals got outdated and were removed:
Open in Gerrit

Related details

Attention is currently required from:
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement is not satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: newpatchset
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 6
unsatisfied_requirement
satisfied_requirement
open
diffy

David Chase (Gerrit)

unread,
May 18, 2026, 2:18:59 PM (18 hours ago) May 18
to Alexander Musman, goph...@pubsubhelper.golang.org, golang...@luci-project-accounts.iam.gserviceaccount.com, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Alexander Musman, Cherry Mui and Junyang Shao

David Chase voted

Auto-Submit+1
Code-Review+2
Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Alexander Musman
  • Cherry Mui
  • Junyang Shao
Submit Requirements:
  • requirement satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 6
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: Alexander Musman <alexande...@gmail.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Mon, 18 May 2026 18:18:56 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
satisfied_requirement
unsatisfied_requirement
open
diffy

Alexander Musman (Gerrit)

unread,
2:50 AM (5 hours ago) 2:50 AM
to goph...@pubsubhelper.golang.org, golang...@luci-project-accounts.iam.gserviceaccount.com, David Chase, Cherry Mui, Junyang Shao, golang-co...@googlegroups.com
Attention needed from Cherry Mui, David Chase and Junyang Shao

Alexander Musman voted Commit-Queue+1

Commit-Queue+1
Open in Gerrit

Related details

Attention is currently required from:
  • Cherry Mui
  • David Chase
  • Junyang Shao
Submit Requirements:
  • requirement satisfiedCode-Review
  • requirement satisfiedNo-Unresolved-Comments
  • requirement is not satisfiedReview-Enforcement
  • requirement is not satisfiedTryBots-Pass
Inspect html for hidden footers to help with email filtering. To unsubscribe visit settings. DiffyGerrit
Gerrit-MessageType: comment
Gerrit-Project: go
Gerrit-Branch: dev.simd
Gerrit-Change-Id: If09402452ed5a2279b49788797ce0b8e7e07a5f5
Gerrit-Change-Number: 773240
Gerrit-PatchSet: 7
Gerrit-Owner: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Alexander Musman <alexande...@gmail.com>
Gerrit-Reviewer: Cherry Mui <cher...@google.com>
Gerrit-Reviewer: David Chase <drc...@google.com>
Gerrit-Reviewer: Junyang Shao <shaoj...@google.com>
Gerrit-Attention: Cherry Mui <cher...@google.com>
Gerrit-Attention: David Chase <drc...@google.com>
Gerrit-Attention: Junyang Shao <shaoj...@google.com>
Gerrit-Comment-Date: Tue, 19 May 2026 06:49:55 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
satisfied_requirement
unsatisfied_requirement
open
diffy
Reply all
Reply to author
Forward
0 new messages
diff --git a/src/simd/archsimd/_gen/main.go b/src/simd/archsimd/_gen/main.go
index 5061de7..8861921 100644
--- a/src/simd/archsimd/_gen/main.go
+++ b/src/simd/archsimd/_gen/main.go
@@ -20,8 +20,9 @@
flagTmplgen = flag.Bool("tmplgen", true, "run tmplgen generator")
flagSimdgen = flag.Bool("simdgen", true, "run simdgen generator")

- flagN = flag.Bool("n", false, "dry run")
- flagXedPath = flag.String("xedPath", defaultXedPath, "load XED datafile from `path`, which must be the XED obj/dgen directory")
+ flagN = flag.Bool("n", false, "dry run")
+ flagXedPath = flag.String("xedPath", defaultXedPath, "load XED datafile from `path`, which must be the XED obj/dgen directory")
+ flagArm64Path = flag.String("arm64Path", os.Getenv("ARM64_ISA_PATH"), "load ARM64 ISA XML definitions from `path`")
)

var goRoot string
@@ -65,8 +66,13 @@
os.Exit(1)
}

- // Regenerate the XED-derived SIMD files
- goRun("-C", "simdgen", ".", "-o", "godefs", "-goroot", goRoot, "-xedPath", prettyPath("./simdgen", xedPath), "go.yaml", "types.yaml", "categories.yaml")
+ // Regenerate the XED-derived SIMD files (amd64)
+ goRun("-C", "simdgen", ".", "-o", "godefs", "-goroot", goRoot, "-xedPath", prettyPath("./simdgen", xedPath), "go_amd64.yaml", "types.yaml", "categories.yaml")
+
+ // Regenerate the ARM64-derived SIMD files, if requested
+ if *flagArm64Path != "" {
+ goRun("-C", "simdgen", ".", "-o", "godefs", "-goroot", goRoot, "-arm64Path", prettyPath("./simdgen", *flagArm64Path), "go_arm64.yaml", "types.yaml", "categories.yaml")
+ }

// simdgen produces SSA rule files, so update the SSA files
goRun("-C", prettyPath(".", filepath.Join(goRoot, "src", "cmd", "compile", "internal", "ssa", "_gen")), ".")
diff --git a/src/simd/archsimd/_gen/simdgen/main.go b/src/simd/archsimd/_gen/simdgen/main.go
index ed5f14f..3e7c82d 100644
--- a/src/simd/archsimd/_gen/simdgen/main.go
+++ b/src/simd/archsimd/_gen/simdgen/main.go
@@ -50,13 +50,15 @@
// simdgen can also generate Go definitions of SIMD mappings:
// To generate go files to the go root, run:
//
// go run . -xedPath $XEDPATH -o godefs -goroot $PATH/TO/go go.yaml categories.yaml types.yaml
//
-// TODO: go.yaml for ARM64 will be added in follow-on commits
+// For ARM64:
+//
+// go run . -arm64Path $ARM64_ISA_PATH -o godefs -goroot $PATH/TO/go go_arm64.yaml categories.yaml types.yaml
//
// types.yaml is already written, it specifies the shapes of vectors.
// categories.yaml and go.yaml contains definitions that unifies with types.yaml and XED
// data, you can find an example in ops/AddSub/.
//
// When generating Go definitions, simdgen do 3 "magic"s:
// - It splits masked operations(with op's [Masked] field set) to const and non const:
@@ -205,7 +207,8 @@
}
inputs = append(inputs, defs)

- if filepath.Base(path) == "go.yaml" {
+ base := filepath.Base(path)
+ if base == "go_amd64.yaml" || base == "go_arm64.yaml" {
// These must all be used in the final result
for def := range defs.Summands() {
must[def] = struct{}{}
@@ -50,13 +50,15 @@
// To generate go files to the go root, run:
//
-// go run . -xedPath $XEDPATH -o godefs -goroot $PATH/TO/go go.yaml categories.yaml types.yaml
+// go run . -xedPath $XEDPATH -o godefs -goroot $PATH/TO/go go_amd64.yaml categories.yaml types.yaml
//
@@ -50,13 +50,15 @@
//
// types.yaml is already written, it specifies the shapes of vectors.
-// categories.yaml and go.yaml contains definitions that unifies with types.yaml and XED
-// data, you can find an example in ops/AddSub/.
+// categories.yaml and go_<arch>.yaml contain definitions that unify with types.yaml and
+// XED/ARM64 ISA data, you can find an example in ops/AddSub/.
//
// When generating Go definitions, simdgen do 3 "magic"s: